Enum libp2p_core::identity::PublicKey
source · pub enum PublicKey {
Ed25519(PublicKey),
Rsa(PublicKey),
Secp256k1(PublicKey),
Ecdsa(PublicKey),
}Expand description
The public key of a node’s identity keypair.
Variants
Ed25519(PublicKey)
👎Deprecated since 0.1.0: This enum will be made opaque in the future, use <code>PublicKey::into_ed25519</code> instead.
Available on crate feature
ed25519 only.A public Ed25519 key.
Rsa(PublicKey)
👎Deprecated since 0.1.0: This enum will be made opaque in the future, use <code>PublicKey::into_rsa</code> instead.
Available on crate feature
rsa and non-WebAssembly only.A public RSA key.
Secp256k1(PublicKey)
👎Deprecated since 0.1.0: This enum will be made opaque in the future, use <code>PublicKey::into_secp256k1</code> instead.
Available on crate feature
secp256k1 only.A public Secp256k1 key.
Ecdsa(PublicKey)
👎Deprecated since 0.1.0: This enum will be made opaque in the future, use <code>PublicKey::into_ecdsa</code> instead.
Available on crate feature
ecdsa only.A public ECDSA key.
Implementations
sourceimpl PublicKey
impl PublicKey
sourcepub fn verify(&self, msg: &[u8], sig: &[u8]) -> bool
pub fn verify(&self, msg: &[u8], sig: &[u8]) -> bool
Verify a signature for a message using this public key, i.e. check that the signature has been produced by the corresponding private key (authenticity), and that the message has not been tampered with (integrity).
pub fn into_ed25519(self) -> Option<PublicKey>
Available on crate feature
ed25519 only.pub fn into_secp256k1(self) -> Option<PublicKey>
Available on crate feature
secp256k1 only.pub fn into_rsa(self) -> Option<PublicKey>
Available on crate feature
rsa and non-WebAssembly only.pub fn into_ecdsa(self) -> Option<PublicKey>
Available on crate feature
ecdsa only.sourcepub fn to_protobuf_encoding(&self) -> Vec<u8, Global>
pub fn to_protobuf_encoding(&self) -> Vec<u8, Global>
Encode the public key into a protobuf structure for storage or exchange with other nodes.
sourcepub fn from_protobuf_encoding(bytes: &[u8]) -> Result<PublicKey, DecodingError>
pub fn from_protobuf_encoding(bytes: &[u8]) -> Result<PublicKey, DecodingError>
Decode a public key from a protobuf structure, e.g. read from storage or received from another node.
sourcepub fn to_peer_id(&self) -> PeerId
Available on crate feature peerid only.
pub fn to_peer_id(&self) -> PeerId
peerid only.Convert the PublicKey into the corresponding PeerId.