Struct libp2p_core::muxing::SingletonMuxer
source · [−]pub struct SingletonMuxer<TSocket> { /* private fields */ }Expand description
Implementation of StreamMuxer that allows only one substream on top of a connection,
yielding the connection itself.
Applying this muxer on a connection doesn’t read or write any data on the connection itself. Most notably, no protocol is negotiated.
Implementations
sourceimpl<TSocket> SingletonMuxer<TSocket>
impl<TSocket> SingletonMuxer<TSocket>