Enum libp2p_core::network::DialError
source · [−]pub enum DialError<THandler> {
ConnectionLimit {
limit: ConnectionLimit,
handler: THandler,
},
LocalPeerId {
handler: THandler,
},
}Expand description
Possible (synchronous) errors when dialing a peer.
Variants
ConnectionLimit
The dialing attempt is rejected because of a connection limit.
LocalPeerId
The dialing attempt is rejected because the peer being dialed is the local peer.