Struct libp2p_core::network::peer::ConnectedPeer
source · [−]pub struct ConnectedPeer<'a, TTrans, THandler> where
TTrans: Transport,
THandler: IntoConnectionHandler, { /* private fields */ }Expand description
The representation of a peer in a Network to whom at least
one established connection exists. There may also be additional ongoing
dialing attempts to the peer.
Implementations
sourceimpl<'a, TTrans, THandler> ConnectedPeer<'a, TTrans, THandler> where
TTrans: Transport,
<TTrans as Transport>::Error: Send + 'static,
THandler: IntoConnectionHandler,
impl<'a, TTrans, THandler> ConnectedPeer<'a, TTrans, THandler> where
TTrans: Transport,
<TTrans as Transport>::Error: Send + 'static,
THandler: IntoConnectionHandler,
pub fn id(&self) -> &PeerId
sourcepub fn connection(
&mut self,
id: ConnectionId
) -> Option<EstablishedConnection<'_, <<THandler as IntoConnectionHandler>::Handler as ConnectionHandler>::InEvent>>
pub fn connection(
&mut self,
id: ConnectionId
) -> Option<EstablishedConnection<'_, <<THandler as IntoConnectionHandler>::Handler as ConnectionHandler>::InEvent>>
Obtains an established connection to the peer by ID.
sourcepub fn num_connections(&self) -> u32
pub fn num_connections(&self) -> u32
The number of established connections to the peer.
sourcepub fn is_dialing(&self) -> bool
pub fn is_dialing(&self) -> bool
Checks whether there is an ongoing dialing attempt to the peer.
Returns true iff ConnectedPeer::into_dialing returns Some.
sourcepub fn into_dialing(self) -> Option<DialingPeer<'a, TTrans, THandler>>
pub fn into_dialing(self) -> Option<DialingPeer<'a, TTrans, THandler>>
Converts this peer into a DialingPeer, if there is an ongoing
dialing attempt, None otherwise.
sourcepub fn connections(
&mut self
) -> EstablishedConnectionIter<'_, impl Iterator<Item = ConnectionId>, <<THandler as IntoConnectionHandler>::Handler as ConnectionHandler>::InEvent>
pub fn connections(
&mut self
) -> EstablishedConnectionIter<'_, impl Iterator<Item = ConnectionId>, <<THandler as IntoConnectionHandler>::Handler as ConnectionHandler>::InEvent>
Gets an iterator over all established connections to the peer.
sourcepub fn some_connection(
&mut self
) -> EstablishedConnection<'_, <<THandler as IntoConnectionHandler>::Handler as ConnectionHandler>::InEvent>
pub fn some_connection(
&mut self
) -> EstablishedConnection<'_, <<THandler as IntoConnectionHandler>::Handler as ConnectionHandler>::InEvent>
Obtains some established connection to the peer.
sourcepub fn disconnect(self) -> DisconnectedPeer<'a, TTrans, THandler>
pub fn disconnect(self) -> DisconnectedPeer<'a, TTrans, THandler>
Disconnects from the peer, closing all connections.