Struct libp2p_core::network::peer::DialingAttemptIter
source · [−]pub struct DialingAttemptIter<'a, THandler: IntoConnectionHandler, TTrans: Transport> { /* private fields */ }Expand description
An iterator over the ongoing dialing attempts to a peer.
Implementations
sourceimpl<'a, THandler: IntoConnectionHandler, TTrans: Transport> DialingAttemptIter<'a, THandler, TTrans>
impl<'a, THandler: IntoConnectionHandler, TTrans: Transport> DialingAttemptIter<'a, THandler, TTrans>
sourcepub fn next(&mut self) -> Option<DialingAttempt<'_, THandler>>
pub fn next(&mut self) -> Option<DialingAttempt<'_, THandler>>
Obtains the next dialing connection, if any.
sourcepub fn into_first<'b>(self) -> Option<DialingAttempt<'b, THandler>> where
'a: 'b,
pub fn into_first<'b>(self) -> Option<DialingAttempt<'b, THandler>> where
'a: 'b,
Returns the first connection, if any, consuming the iterator.