pub enum InterruptError {
    ReachAttemptNotFound,
    AlreadyReached,
}
Reach attempt interrupt errors.

Variants

ReachAttemptNotFound

An invalid reach attempt has been used to try to interrupt. The task entry is vacant; it needs to be added first via add_reach_attempt (with the TaskState set to Pending) before we try to connect.

AlreadyReached

The task has already connected to the node; interrupting a reach attempt is thus redundant as it has already completed. Thus, the reach attempt that has tried to be used is no longer valid, since already reached.