pub struct CollectionReachEvent<'a, TInEvent: 'a, TOutEvent: 'a, THandler: 'a, TReachErr, THandlerErr: 'a> { /* private fields */ }
Event that happens when we reach a node.

Implementations

Returns the peer id of the node that has been reached.

Returns the reach attempt that reached the node.

Returns true if accepting this reached node would replace an existing connection to that node.

Accepts the new node.

Denies the node.

Has the same effect as dropping the event without accepting it.