Structs

Implementation of Stream that handles a collection of nodes.
Access to a task in the collection.
Identifier for a future that attempts to reach a node.

Enums

Event that can happen on the HandledNodesTasks.
Error that can happen in a task.