Struct libp2p_core::nodes::handled_node_tasks::HandledNodesTasks
source · pub struct HandledNodesTasks<TInEvent, TOutEvent, THandler, TReachErr, THandlerErr> { /* private fields */ }Expand description
Implementation of Stream that handles a collection of nodes.
Implementations
sourceimpl<TInEvent, TOutEvent, THandler, TReachErr, THandlerErr> HandledNodesTasks<TInEvent, TOutEvent, THandler, TReachErr, THandlerErr>
impl<TInEvent, TOutEvent, THandler, TReachErr, THandlerErr> HandledNodesTasks<TInEvent, TOutEvent, THandler, TReachErr, THandlerErr>
sourcepub fn add_reach_attempt<TFut, TMuxer>(
&mut self,
future: TFut,
handler: THandler
) -> TaskIdwhere
TFut: Future<Item = (PeerId, TMuxer), Error = TReachErr> + Send + 'static,
THandler: NodeHandler<Substream = Substream<TMuxer>, InEvent = TInEvent, OutEvent = TOutEvent, Error = THandlerErr> + Send + 'static,
TReachErr: Error + Send + 'static,
THandlerErr: Error + Send + 'static,
TInEvent: Send + 'static,
TOutEvent: Send + 'static,
THandler::OutboundOpenInfo: Send + 'static,
TMuxer: StreamMuxer + Send + Sync + 'static,
TMuxer::OutboundSubstream: Send + 'static,
pub fn add_reach_attempt<TFut, TMuxer>(
&mut self,
future: TFut,
handler: THandler
) -> TaskIdwhere
TFut: Future<Item = (PeerId, TMuxer), Error = TReachErr> + Send + 'static,
THandler: NodeHandler<Substream = Substream<TMuxer>, InEvent = TInEvent, OutEvent = TOutEvent, Error = THandlerErr> + Send + 'static,
TReachErr: Error + Send + 'static,
THandlerErr: Error + Send + 'static,
TInEvent: Send + 'static,
TOutEvent: Send + 'static,
THandler::OutboundOpenInfo: Send + 'static,
TMuxer: StreamMuxer + Send + Sync + 'static,
TMuxer::OutboundSubstream: Send + 'static,
Adds to the collection a future that tries to reach a node.
This method spawns a task dedicated to resolving this future and processing the node’s events.
sourcepub fn broadcast_event(&mut self, event: &TInEvent)where
TInEvent: Clone,
pub fn broadcast_event(&mut self, event: &TInEvent)where
TInEvent: Clone,
Sends an event to all the tasks, including the pending ones.
sourcepub fn task(&mut self, id: TaskId) -> Option<Task<'_, TInEvent>>
pub fn task(&mut self, id: TaskId) -> Option<Task<'_, TInEvent>>
Grants access to an object that allows controlling a task of the collection.
Returns None if the task id is invalid.
sourcepub fn tasks<'a>(&'a self) -> impl Iterator<Item = TaskId> + 'a
pub fn tasks<'a>(&'a self) -> impl Iterator<Item = TaskId> + 'a
Returns a list of all the active tasks.
sourcepub fn poll(
&mut self
) -> Async<HandledNodesEvent<TOutEvent, THandler, TReachErr, THandlerErr>>
pub fn poll(
&mut self
) -> Async<HandledNodesEvent<TOutEvent, THandler, TReachErr, THandlerErr>>
Provides an API similar to Stream, except that it cannot produce an error.