[−][src]Enum libp2p_core::nodes::node::NodeEvent
Event that can happen on the NodeStream.
Variants
InboundSubstreamA new inbound substream arrived.
Fields of InboundSubstream
substream: Substream<TMuxer>The newly-opened substream.
OutboundSubstreamAn outbound substream has successfully been opened.
Fields of OutboundSubstream
user_data: TUserDataUser data that has been passed to the open_substream method.
substream: Substream<TMuxer>The newly-opened substream.
OutboundClosedAn outbound substream couldn't be opened because the muxer is no longer capable of opening more substreams.
Fields of OutboundClosed
InboundClosedThe inbound side of the muxer has been closed. No more inbound substreams will be produced.