pub struct NodeStream<TMuxer, TUserData>where
    TMuxer: StreamMuxer,
{ /* private fields */ }
Implementation of Stream that handles a node.

The stream will receive substreams and can be used to open new outgoing substreams. Destroying the NodeStream will not close the existing substreams.

The stream will close once both the inbound and outbound channels are closed, and no more outbound substream attempt is pending.

Implementations

Creates a new node events stream.

Starts the process of opening a new outbound substream.

Returns an error if the outbound side of the muxer is closed.

After calling this method, polling the stream should eventually produce either an OutboundSubstream event or an OutboundClosed event containing the user data that has been passed to this method.

Returns true if the inbound channel of the muxer is open.

If true is returned, more inbound substream will be produced.

Returns true if the outbound channel of the muxer is open.

If true is returned, more outbound substream can be opened. Otherwise, calling open_substream will return an Err.

Destroys the node stream and returns all the pending outbound substreams.

Destroys all outbound streams and returns the corresponding user data.

Trigger node shutdown.

After this, NodeStream::poll will eventually produce None, when both endpoints are closed.