pub struct IncomingConnectionEvent<'a, TTrans: 'a, TInEvent: 'a, TOutEvent: 'a, THandler: 'a, THandlerErr: 'a>where
    TTrans: Transport,
{ /* private fields */ }
A new connection arrived on a listener.

Implementations

Starts processing the incoming connection and sets the handler to use for it.

Same as accept, but accepts a closure that turns a ConnectedPoint into a handler.

Address of the listener that received the connection.

Address used to send back data to the dialer.

Builds the ConnectedPoint corresponding to the incoming connection.