Struct libp2p_core::PeerId

source ·
pub struct PeerId { /* private fields */ }
Identifier of a peer of the network.

The data is a multihash of the public key of the peer.

Implementations

Builds a PeerId from a public key.

Checks whether data is a valid PeerId. If so, returns the PeerId. If not, returns back the data as an error.

Turns a Multihash into a PeerId. If the multihash doesn’t use the correct algorithm, returns back the data as an error.

Generates a random peer ID from a cryptographically secure PRNG.

This is useful for randomly walking on a DHT, or for testing purposes.

Returns a raw bytes representation of this PeerId.

Note that this is not the same as the public key of the peer.

Returns a raw bytes representation of this PeerId.

Note that this is not the same as the public key of the peer.

Returns a base-58 encoded string of this PeerId.

Returns the raw bytes of the hash of this PeerId.

Checks whether the public key passed as parameter matches the public key of this PeerId.

Returns None if this PeerIds hash algorithm is not supported when encoding the given public key, otherwise Some boolean as the result of an equality check.