pub struct PollParameters<'a, TTopology: 'a> { /* private fields */ }
Parameters passed to poll() that the NetworkBehaviour has access to.

Implementations

Returns a reference to the topology of the network.

Returns the list of protocol the behaviour supports when a remote negotiates a protocol on an inbound substream.

The iterator’s elements are the ASCII names as reported on the wire.

Note that the list is computed once at initialization and never refreshed.

Returns the list of the addresses we’re listening on.

Returns the list of the addresses nodes can use to reach us.

Returns the public key of the local node.

Returns the peer id of the local node.

Calls the nat_traversal method on the underlying transport of the Swarm.