Struct libp2p_core::swarm::Swarm

source ·
pub struct Swarm<TTransport, TBehaviour, TTopology>where
    TTransport: Transport,
    TBehaviour: NetworkBehaviour<TTopology>,
{ /* private fields */ }
Contains the state of the network, plus the way it should behave.

Implementations

Builds a new Swarm.

Returns the transport passed when building this object.

Starts listening on the given address.

Returns an error if the address is not supported. On success, returns an alternative version of the address.

Tries to dial the given address.

Returns an error if the address is not supported.

Tries to reach the given peer using the elements in the topology.

Has no effect if we are already connected to that peer, or if no address is known for the peer.

Returns an iterator that produces the list of addresses we’re listening on.

Returns the peer ID of the swarm passed as parameter.

Returns the topology of the swarm.

Returns the topology of the swarm.