pub trait NetworkBehaviourEventProcess<TEvent> {
    fn inject_event(&mut self, event: TEvent);
}
Used when deriving NetworkBehaviour. When deriving NetworkBehaviour, must be implemented for all the possible event types generated by the various fields.

Required Methods

Called when one of the fields of the type you’re deriving NetworkBehaviour on generates an event.

Implementors