pub struct CollectionStream<TInEvent, TOutEvent, THandler, TReachErr, THandlerErr> { /* private fields */ }
Implementation of Stream that handles a collection of nodes.

Implementations

Creates a new empty collection.

Adds to the collection a future that tries to reach a remote.

This method spawns a task dedicated to resolving this future and processing the node’s events.

Interrupts a reach attempt.

Returns Ok if something was interrupted, and Err if the ID is not or no longer valid.

Sends an event to all nodes.

Grants access to an object that allows controlling a peer of the collection.

Returns None if we don’t have a connection to this peer.

Returns true if we are connected to the given peer.

This will return true only after a NodeReached event has been produced by poll().

Returns a list of all the active connections.

Does not include reach attempts that haven’t reached any target yet.

Provides an API similar to Stream, except that it cannot error.

Note: we use a regular poll method instead of implementing Stream in order to remove the Err variant, but also because we want the CollectionStream to stay borrowed if necessary.