pub enum NodeEvent<TMuxer, TUserData>where
    TMuxer: StreamMuxer,
{ InboundSubstream { substream: Substream<TMuxer>, }, OutboundSubstream { user_data: TUserData, substream: Substream<TMuxer>, }, OutboundClosed { user_data: TUserData, }, InboundClosed, }
Event that can happen on the NodeStream.

Variants

InboundSubstream

Fields

substream: Substream<TMuxer>

The newly-opened substream.

A new inbound substream arrived.

OutboundSubstream

Fields

user_data: TUserData

User data that has been passed to the open_substream method.

substream: Substream<TMuxer>

The newly-opened substream.

An outbound substream has successfully been opened.

OutboundClosed

Fields

user_data: TUserData

User data that has been passed to the open_substream method.

An outbound substream couldn’t be opened because the muxer is no longer capable of opening more substreams.

InboundClosed

The inbound side of the muxer has been closed. No more inbound substreams will be produced.