Enum libp2p_core::nodes::node::NodeEvent
source · pub enum NodeEvent<TMuxer, TUserData>where
TMuxer: StreamMuxer,{
InboundSubstream {
substream: Substream<TMuxer>,
},
OutboundSubstream {
user_data: TUserData,
substream: Substream<TMuxer>,
},
OutboundClosed {
user_data: TUserData,
},
InboundClosed,
}Expand description
Event that can happen on the NodeStream.
Variants
InboundSubstream
Fields
substream: Substream<TMuxer>The newly-opened substream.
A new inbound substream arrived.
OutboundSubstream
Fields
substream: Substream<TMuxer>The newly-opened substream.
An outbound substream has successfully been opened.
OutboundClosed
An outbound substream couldn’t be opened because the muxer is no longer capable of opening more substreams.
InboundClosed
The inbound side of the muxer has been closed. No more inbound substreams will be produced.