Module libp2p_core::protocols_handler
source · Structs
Implementation of
ProtocolsHandler that doesn’t handle anything.Wrapper around a protocol handler that turns the input event into something else.
Wrapper around a protocol handler that turns the output event into something else.
Wraps around an implementation of
ProtocolsHandler, and implements NodeHandler.Prototype for a
NodeHandlerWrapper.Implementation of
ProtocolsHandler that combines two protocols into one.Enums
Event produced by a handler.
Error that can happen on an outbound substream opening attempt.
Traits
Handler for a set of protocols for a specific connection with a remote.