pub enum NetworkBehaviourAction<TInEvent, TOutEvent> {
    GenerateEvent(TOutEvent),
    DialAddress {
        address: Multiaddr,
    },
    DialPeer {
        peer_id: PeerId,
    },
    SendEvent {
        peer_id: PeerId,
        event: TInEvent,
    },
    ReportObservedAddr {
        address: Multiaddr,
    },
}
Action to perform.

Variants

GenerateEvent(TOutEvent)

Generate an event for the outside.

DialAddress

Fields

address: Multiaddr

The address to dial.

Instructs the swarm to dial the given multiaddress without any expectation of a peer id.

DialPeer

Fields

peer_id: PeerId

The peer to try reach.

Instructs the swarm to try reach the given peer.

SendEvent

Fields

peer_id: PeerId

The peer which to send the message to.

event: TInEvent

Event to send to the peer.

If we’re connected to the given peer, sends a message to the protocol handler.

If we’re not connected to this peer, does nothing. If necessary, the implementation of NetworkBehaviour is supposed to track which peers we are connected to.

ReportObservedAddr

Fields

address: Multiaddr

The address we’re being observed as.

Reports that a remote observes us as this address.

The swarm will pass this address through the transport’s NAT traversal.